import { asyncRoutes, constantRoutes } from '@/router'
import { getToken } from '@/utils/auth'
import { getInfo } from '@/api/user'

/**
 * Use meta.role to determine if the current user has permission
 * @param roles
 * @param route
 */
function hasPermission(roles, route) {
  if (route.meta && route.meta.roles) {
    return roles.some(role => route.meta.roles.includes(role))
  } else {
    return true
  }
}

/**
 * Filter asynchronous routing tables by recursion
 * @param routes asyncRoutes
 * @param roles
 */
export function filterAsyncRoutes(routes, roles) {
  const res = []

  routes.forEach(route => {
    const tmp = { ...route }
    if (hasPermission(roles, tmp)) {
      if (tmp.children) {
        tmp.children = filterAsyncRoutes(tmp.children, roles)
      }
      res.push(tmp)
    }
  })

  return res
}

const state = {
  routes: [],
  addRoutes: []
}

const mutations = {
  SET_ROUTES: (state, routes) => {
    state.addRoutes = routes
    state.routes = constantRoutes.concat(routes)
  }
}

const actions = {
  generateRoutes({ commit }, userInfo) {
    // eslint-disable-next-line no-async-promise-executor
    return new Promise(async resolve => {
      let accessedRoutes
      if (userInfo.roles.includes('admin')) {
        accessedRoutes = asyncRoutes || []
      } else {
        accessedRoutes = filterAsyncRoutes(asyncRoutes, userInfo.roles)
      }
      try {
        const res = await getInfo(getToken())
        const data = res.data
        if (data.personnelType === 1) {
          accessedRoutes[7].children.unshift({
            path: 'user',
            name: 'User',
            component: () => import('@/views/sys/user-list'),
            meta: { title: '后台用户管理', icon: 'el-icon-s-custom' }
          })
          commit('SET_ROUTES', accessedRoutes)
          resolve(accessedRoutes)
        } else {
          commit('SET_ROUTES', accessedRoutes)
          resolve(accessedRoutes)
        }
      } catch (error) {
        commit('SET_ROUTES', accessedRoutes)
        resolve(accessedRoutes)
      }
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
